@@ -15,7 +15,7 @@ __all__ = (
     "find_legacy_steam_runtime_path", "get_appinfo_sections",
     "get_proton_appid", "find_steam_proton_app", "find_appid_proton_prefix",
     "find_proton_app", "get_steam_lib_paths", "get_compat_tool_dirs",
-    "get_proton_installations", "get_custom_proton_installations",
+    "get_custom_proton_installations_in_dir", "get_custom_proton_installations",
     "find_current_steamid3", "get_appid_from_shortcut",
     "get_custom_windows_shortcuts", "get_steam_apps"
 )
@@ -168,13 +168,13 @@ class SteamApp(object):
             return None
 
         try:
-            vdf_data = vdf.loads(content)
+            vdf_data = lower_dict(vdf.loads(content))
         except SyntaxError:
             logger.warning("Skipping malformed appmanifest %s", path)
             return None
 
         try:
-            app_state = vdf_data["AppState"]
+            app_state = vdf_data["appstate"]
         except KeyError:
             # Some appmanifest files may be empty. Ignore those.
             logger.info("Skipping empty appmanifest %s", path)
@@ -187,7 +187,12 @@ class SteamApp(object):
         # Use case-insensitive field names to deal with these.
         app_state = lower_dict(app_state)
         appid = int(app_state["appid"])
-        name = app_state["name"]
+
+        try:
+            name = app_state["name"]
+        except KeyError:
+            # Older app installations also use `userconfig/name`
+            name = app_state["userconfig"]["name"]
 
         # Proton prefix may exist on a different library
         prefix_path = find_appid_proton_prefix(
@@ -196,28 +201,18 @@ class SteamApp(object):
 
         install_path = Path(path).parent / "common" / app_state["installdir"]
 
-        required_tool_appid = None
-
         # Check if the app requires another app. This is the case with
         # newer versions of Proton, which use Steam Runtimes installed as
         # normal Steam apps
-        tool_manifest_path = install_path / "toolmanifest.vdf"
         try:
-            tool_manifest_content = tool_manifest_path.read_text()
-
-            if tool_manifest_content == "":
-                logger.warning(
-                    "Tool manifest for %s is empty. You may need to reinstall "
-                    "the application.",
-                    name
-                )
-                return None
-
-            tool_manifest = vdf.loads(tool_manifest_content)
-            required_tool_appid = \
-                tool_manifest["manifest"].get("require_tool_appid", None)
-        except FileNotFoundError:
-            pass
+            required_tool_appid = _get_required_tool_appid(install_path)
+        except ValueError:
+            logger.warning(
+                "Tool manifest for %s is empty. You may need to reinstall "
+                "the application.",
+                name
+            )
+            return None
 
         return cls(
             appid=appid, name=name, prefix_path=prefix_path,
@@ -225,6 +220,25 @@ class SteamApp(object):
         )
 
 
+def _get_required_tool_appid(path):
+    """
+    Get the required tool app ID for the Proton installation at the given path
+
+    :raises ValueError: Tool manifest is empty
+    """
+    tool_manifest_path = path / "toolmanifest.vdf"
+    try:
+        tool_manifest_content = tool_manifest_path.read_text()
+
+        if tool_manifest_content == "":
+            raise ValueError("Tool manifest is empty")
+
+        tool_manifest = lower_dict(vdf.loads(tool_manifest_content))
+        return tool_manifest["manifest"].get("require_tool_appid", None)
+    except FileNotFoundError:
+        return None
+
+
 def find_steam_path():
     """
     Try to discover default Steam dir using common locations and return the
@@ -358,7 +372,9 @@ def get_appinfo_sections(path):
         vdf_section_size = entry_size - 40
 
         i += section_size
+
         vdf_d = vdf.binary_loads(data[i:i+vdf_section_size])
+        vdf_d = lower_dict(vdf_d)
         sections.append(vdf_d)
 
         i += vdf_section_size
@@ -430,12 +446,12 @@ def find_steam_proton_app(steam_path, steam_apps, appid=None):
     config_vdf_path = steam_path / "config" / "config.vdf"
     content = config_vdf_path.read_text()
 
-    vdf_data = vdf.loads(content)
+    vdf_data = lower_dict(vdf.loads(content))
     # ToolMapping seems to be used in older Steam beta releases
     try:
         tool_mapping = (
-            vdf_data["InstallConfigStore"]["Software"]["Valve"]["Steam"]
-                    ["ToolMapping"]
+            vdf_data["installconfigstore"]["software"]["valve"]["steam"]
+                    ["toolmapping"]
         )
     except KeyError:
         tool_mapping = {}
@@ -444,8 +460,8 @@ def find_steam_proton_app(steam_path, steam_apps, appid=None):
     # We'll prioritize this if it exists
     try:
         compat_tool_mapping = (
-            vdf_data["InstallConfigStore"]["Software"]["Valve"]["Steam"]
-                    ["CompatToolMapping"]
+            vdf_data["installconfigstore"]["software"]["valve"]["steam"]
+                    ["compattoolmapping"]
         )
     except KeyError:
         compat_tool_mapping = {}
@@ -594,12 +610,22 @@ def get_steam_lib_paths(steam_path):
         """
         Parse the Steam library folders in the VDF file using the given data
         """
-        vdf_data = vdf.loads(data)
+        vdf_data = lower_dict(vdf.loads(data))
         # Library folders have integer field names in ascending order
-        library_folders = [
-            Path(value) for key, value in vdf_data["LibraryFolders"].items()
+        library_entries = [
+            value for key, value in vdf_data["libraryfolders"].items()
             if key.isdigit()
         ]
+        library_folders = []
+
+        for value in library_entries:
+            if isinstance(value, dict):
+                # Library data is stored in a dict in newer Steam releases
+                library_folders.append(Path(value["path"]))
+            else:
+                # Older releases just store the library path as a string
+                # and nothing else
+                library_folders.append(Path(value))
 
         logger.info(
             "Found %d Steam library folders", len(library_folders)
@@ -641,11 +667,11 @@ def get_compat_tool_dirs(steam_root):
     return paths
 
 
-def get_proton_installations(compat_tool_dir):
+def get_custom_proton_installations_in_dir(compat_tool_dir):
     """
-    Return a list of custom Proton installations as a list of SteamApp objects
+    Return a list of custom Proton installations in the given directory
+    as a list of SteamApp objects
     """
-
     if not compat_tool_dir.is_dir():
         return []
 
@@ -658,10 +684,21 @@ def get_proton_installations(compat_tool_dir):
         content = vdf_path.read_text()
 
         vdf_data = vdf.loads(content)
-        internal_name = list(
-            vdf_data["compatibilitytools"]["compat_tools"].keys())[0]
-        tool_info = vdf_data["compatibilitytools"]["compat_tools"][
-            internal_name]
+
+        # Traverse to 'compatibilitytools/compat_tools' in a case-insensitive
+        # way. This is done because we can't turn all keys recursively to
+        # lowercase from the get-go; the app name is stored as a key.
+        compat_tools = {k.lower(): v for k, v in vdf_data.items()}
+        compat_tools = compat_tools["compatibilitytools"]
+        compat_tools = {
+            k.lower(): v for k, v in compat_tools.items()
+        }
+        compat_tools = compat_tools["compat_tools"]
+        internal_name = list(compat_tools.keys())[0]
+        tool_info = compat_tools[internal_name]
+
+        # We can now convert the remainder into lowercase
+        tool_info = lower_dict(tool_info)
 
         install_path_name = tool_info["install_path"]
         from_oslist = tool_info["from_oslist"]
@@ -678,17 +715,36 @@ def get_proton_installations(compat_tool_dir):
         else:
             install_path = compat_tool_dir / install_path_name
 
+        # Check if the app requires another app. This is the case with
+        # newer versions of Proton, which use Steam Runtimes installed as
+        # normal Steam apps
+        try:
+            required_tool_appid = _get_required_tool_appid(install_path)
+        except ValueError:
+            logger.warning(
+                "Tool manifest for %s is empty. You may need to reinstall "
+                "the application.",
+                install_path.name
+            )
+            continue
+
         custom_proton_apps.append(
-            SteamApp(name=internal_name, install_path=install_path)
+            SteamApp(
+                name=internal_name, install_path=install_path,
+                required_tool_appid=required_tool_appid
+            )
         )
 
     return custom_proton_apps
 
 
 def get_custom_proton_installations(steam_root):
+    """
+    Get a list of all custom Proton installations as a list of SteamApp objects
+    """
     custom_proton_apps = {}
     for dir_ in get_compat_tool_dirs(steam_root=steam_root):
-        for proton_app in get_proton_installations(dir_):
+        for proton_app in get_custom_proton_installations_in_dir(dir_):
             # If another Proton app exists with the same name, it will
             # be replaced with an installation that has higher precedence
             # here
@@ -711,7 +767,7 @@ def find_current_steamid3(steam_path):
     loginusers_path = steam_path / "config" / "loginusers.vdf"
     try:
         content = loginusers_path.read_text()
-        vdf_data = vdf.loads(content)
+        vdf_data = lower_dict(vdf.loads(content))
     except IOError:
         return None
 
@@ -771,7 +827,7 @@ def get_custom_windows_shortcuts(steam_path):
 
     try:
         content = shortcuts_path.read_bytes()
-        vdf_data = vdf.binary_loads(content)
+        vdf_data = lower_dict(vdf.binary_loads(content))
     except IOError:
         logger.info(
             "Couldn't find custom shortcuts. Maybe none have been created yet?"
